from setuptools import setup, find_packages


def readme():
    with open('README.md', 'r') as f:
        return f.read()


setup(
    name='aio-1c-connect',
    version='0.0.3',
    author='LilKirill00',
    author_email='pc.browsers.1@gmail.com',
    description='This is a library for creating bots in the 1C-Connect environment',
    long_description=readme(),
    long_description_content_type='text/markdown',
    url='https://github.com/LilKirill00/aio-connect',
    packages=find_packages(),
    install_requires=[
        "magic-filter>=1.0.12,<1.1",
        "aiofiles~=23.2.1",
        'aiohttp~=3.9.0',
        'pydantic>=2.4.1,<2.6'
    ],
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "Framework :: AsyncIO",
        "Typing :: Typed",
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Communications :: Chat",
    ],
    keywords='1C-Connect',
    project_urls={
        'GitHub': 'https://github.com/LilKirill00/aio-connect'
    },
    python_requires='>=3.8'
)



from __future__ import annotations

from .base import ConnectMethod

from ..types import UUID
from typing import List


class GetSpecialistsAvailable(ConnectMethod[List[UUID]]):
    """
    Типы запросов: GET
    Описание: Получение специалистов в хорошем статусе по конкретной линии поддержки
    Название: GetSpecialistsAvailable
    URL: /v1/line/specialists/{line_id}/available/

    line_id: UUID = ID линии поддержки

    Метод возвращает id специалистов в статусе "Доступен" по конкретной линии поддержки
    Вызов метода позволяет узнать можно ли назначить специалиста на текущий момент методом
    Source: https://1c-connect.atlassian.net/wiki/spaces/PUBLIC/pages/2167472129/4.2.3.8.
    """

    __returning__ = List[UUID]



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Optional

from .base import ConnectObject

from datetime import datetime
from ..types import UUID


class Subscriptions(ConnectObject):
    """
    Название объекта: Subscriptions
    Описание объекта: Линии, подключенные пользователям

    Source: https://1c-connect.atlassian.net/wiki/spaces/PUBLIC/pages/2322923533/Subscriptions
    """

    line_id: UUID
    """ID линии поддержки"""
    user_id: UUID
    """ID пользователя"""
    subscription_set: datetime
    """Дата начала подписки"""
    subscription_expire_at: Optional[datetime] = None
    """Дата окончания подписки, null когда бессрочная подписка"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            line_id: UUID,
            user_id: UUID,
            subscription_set: datetime,
            subscription_expire_at: Optional[datetime] = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                line_id=line_id,
                user_id=user_id,
                subscription_set=subscription_set,
                subscription_expire_at=subscription_expire_at,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from .base import ConnectMethod


class DelAllHook(ConnectMethod[bool]):
    """
    Типы запросов: DELETE
    Описание: Удаление адресов всех webhook (кроме bot)
    Название: DelAllHook
    URL: /v1/hook/

    Метод удаляет адреса всех webhook (кроме bot).
    Source: https://1c-connect.atlassian.net/wiki/spaces/PUBLIC/pages/1289355653/4.2.1.2.
    """

    __returning__ = bool



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Optional

from .base import ConnectObject

from datetime import datetime
from ..types import UUID


class ServiceRequest(ConnectObject):
    """
    Название объекта: ServiceRequest
    Описание объекта: Заявка Service Desk

    Source: https://1c-connect.atlassian.net/wiki/spaces/PUBLIC/pages/1302888526/ServiceRequest
    """

    request_id: UUID
    """ID Заявки"""
    number: str
    """Номер заявки"""
    created_at: datetime
    """Время создания UTC"""
    channel_id: UUID
    """ID Канала связи"""
    line_id: UUID
    """ID Линии поддержки"""
    initiator_id: UUID
    """ID Пользователя инициатора"""
    executor_id: UUID
    """ID Пользователя исполнителя"""
    status_id: UUID
    """ID Текущая стадия заявки"""
    kind_id: UUID
    """ID Вида услуг"""
    type_id: UUID
    """ID Типа заявок"""
    description: Optional[str] = None
    """Описание заявки"""
    result: Optional[str] = None
    """Описание решения"""
    transaction_id: UUID
    """ID транзакции"""
    updated_at: Optional[datetime] = None
    """Время обновления UTC"""
    duration: Optional[int] = None
    """Длительность работы, сек."""
    summary: Optional[str] = None
    """Тема"""
    priority: Optional[str] = None
    """
    Приоритет. Значения:
        LOW
        STANDARD
        HIGH
    """
    deadline: Optional[str] = None
    """Cрок исполнения"""
    field1: Optional[str] = None
    """Дополнительное настраиваемое поле"""
    field2: Optional[str] = None
    """Дополнительное настраиваемое поле"""
    field3: Optional[str] = None
    """Дополнительное настраиваемое поле"""
    field4: Optional[str] = None
    """Дополнительное настраиваемое поле"""
    field5: Optional[str] = None
    """Дополнительное настраиваемое поле"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            request_id: UUID,
            number: str,
            created_at: datetime,
            channel_id: UUID,
            line_id: UUID,
            initiator_id: UUID,
            executor_id: UUID,
            status_id: UUID,
            kind_id: UUID,
            type_id: UUID,
            description: Optional[str] = None,
            result: Optional[str] = None,
            transaction_id: UUID,
            updated_at: Optional[datetime] = None,
            duration: Optional[int] = None,
            summary: Optional[str] = None,
            priority: Optional[str] = None,
            deadline: Optional[str] = None,
            field1: Optional[str] = None,
            field2: Optional[str] = None,
            field3: Optional[str] = None,
            field4: Optional[str] = None,
            field5: Optional[str] = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                request_id=request_id,
                number=number,
                created_at=created_at,
                channel_id=channel_id,
                line_id=line_id,
                initiator_id=initiator_id,
                executor_id=executor_id,
                status_id=status_id,
                kind_id=kind_id,
                type_id=type_id,
                description=description,
                result=result,
                transaction_id=transaction_id,
                updated_at=updated_at,
                duration=duration,
                summary=summary,
                priority=priority,
                deadline=deadline,
                field1=field1,
                field2=field2,
                field3=field3,
                field4=field4,
                field5=field5,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import Optional, TYPE_CHECKING, Any

from .base import ConnectMethod

from ..types import Subscriptions, UUID


class GetSubscriptions(ConnectMethod[Subscriptions]):
    """
    Типы запросов: GET
    Описание: Получение списка линий, подключенных пользователям
    Название: GetSubscriptions
    URL: /v1/line/subscriptions/

    user_id: Optional[UUID] = ID пользователя
    client_id: Optional[UUID] = ID клинта
    line_id: Optional[UUID] = ID линии поддержки

    Метод возвращает информацию о получаемым линиям пользователями,
        с возможностью отфильтровать по пользователю, линии или клиенту.
    Source: https://1c-connect.atlassian.net/wiki/spaces/PUBLIC/pages/2322923521/4.2.3.4.
    """

    __returning__ = Subscriptions

    user_id: Optional[UUID] = None
    """ID пользователя"""
    client_id: Optional[UUID] = None
    """ID клиента"""
    line_id: Optional[UUID] = None
    """ID линии поддержки"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
                __pydantic__self__,
                *,
                user_id: Optional[UUID] = None,
                client_id: Optional[UUID] = None,
                line_id: Optional[UUID] = None,
                **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                user_id=user_id,
                client_id=client_id,
                line_id=line_id,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import ConnectMethod

from ..types import UUID


class SendMessageConference(ConnectMethod[bool]):
    """
    Типы запросов: POST
    Описание: Отправить сообщение в группу
    Название: SendMessageConference
    URL: /v1/conference/send/message/

    Метод позволяет отправить сообщение в группу от имени участника этой группы.
    Source: https://1c-connect.atlassian.net/wiki/spaces/PUBLIC/pages/1479704633/4.3.1.11.
    """

    __returning__ = bool

    conference_id: UUID
    """ID группы"""
    author_id: UUID
    """ID автора(от чьего имени отправляется сообщение)"""
    text: str
    """Текст сообщения"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            conference_id: UUID,
            author_id: UUID,
            text: str,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                conference_id=conference_id,
                author_id=author_id,
                text=text,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from .base import ConnectMethod

from ..types import Users


class GetSpecialists(ConnectMethod[Users]):
    """
    Типы запросов: GET
    Описание: Получение информации о специалистах
    Название: GetSpecialists
    URL: /v1/line/specialists/

    Метод возвращает информацию о специалистах
    Source: https://1c-connect.atlassian.net/wiki/spaces/PUBLIC/pages/2167373825/4.2.3.7.
    """

    __returning__ = Users
